Name:           jericho-html
Version:        3.3
Release:        2%{?dist}
Summary:        Java library allowing analysis and manipulation of parts of an HTML document

Group:          Development/Libraries
License:        EPL or LGPLv2+
URL:            http://jericho.htmlparser.net/
Source0:        http://downloads.sf.net/jerichohtml/%{name}-%{version}.zip
BuildArch:      noarch
ExcludeArch:    ppc64

BuildRequires:  java-devel >= 1:1.6.0
BuildRequires:  jpackage-utils
BuildRequires:  apache-commons-logging
BuildRequires:  log4j
BuildRequires:  slf4j
#For tests
BuildRequires:  junit
%if 0%{?fedora} >= 20 || 0%{?rhel} >= 7
Requires:       java-headless
%else
Requires:       java >= 1:1.6.0
%endif
Requires:       jpackage-utils


%description
Jericho HTML Parser is a java library allowing analysis and manipulation of
parts of an HTML document, including server-side tags, while reproducing
verbatim any unrecognized or invalid HTML. It also provides high-level HTML
form manipulation functions.

It is an open source library released under both the Eclipse Public License
(EPL) and GNU Lesser General Public License (LGPL). You are therefore free to
use it in commercial applications subject to the terms detailed in either one
of these license documents. 


%package javadoc
Summary:        Javadocs for %{name}
Group:          Documentation
Requires:       jpackage-utils

%description javadoc
This package contains the API documentation for %{name}.


%prep
%setup -q
find \( -name '*.class' -o -name '*.[jw]ar' \) -exec rm -f '{}' +
find \( -name '*.java' -o -name '*.bat' -o -name '*.txt' -o -name '*.jsp' -o -name '*.css' -o -name '*.xml' \) -exec sed -i 's/\r//' '{}' +


%build
export CLASSPATH=$(build-classpath slf4j/api commons-logging log4j)

javac -Xlint -g:none -d classes -encoding Windows-1252 src/java/net/htmlparser/jericho/*.java src/java/net/htmlparser/jericho/nodoc/*.java
jar -cf dist/%{name}.jar -C classes .

javadoc -encoding Windows-1252 -quiet -windowtitle "Jericho HTML Parser %version" -use -d docs/javadoc -subpackages net.htmlparser.jericho -exclude net.htmlparser.jericho.nodoc -noqualifier net.htmlparser.jericho -group "Core Package" src/java/net/htmlparser/jericho/*.java src/java/net/htmlparser/jericho/nodoc/*.java
cp -p docs/src/*.* docs/javadoc

javac -Xlint -g -deprecation -classpath dist/%{name}.jar -d samples/console/classes samples/console/src/*.java


%install
mkdir -p $RPM_BUILD_ROOT%{_javadir}
cp -p dist/%{name}.jar $RPM_BUILD_ROOT%{_javadir}/
mkdir -p $RPM_BUILD_ROOT%{_javadocdir}
cp -rp docs/javadoc $RPM_BUILD_ROOT%{_javadocdir}/%{name}
# Install link for web app
ln -s %{_javadir}/%{name}.jar samples/webapps/JerichoHTML/WEB-INF/lib


%check
mkdir -p test/classes
export CLASSPATH=classes:samples/console/classes:$(build-classpath junit.jar)
javac -Xlint -g -d test/classes test/src/*.java test/src/samples/*.java test/src/net/htmlparser/jericho/*.java
java -classpath $CLASSPATH:test/classes -Djava.util.logging.config.file=test/logging.properties org.junit.runner.JUnitCore TestSuite


%files
%doc licence-epl-1.0.html licence-lgpl-2.1.txt licence.txt
%doc project-description.txt release.txt
%doc samples
%{_javadir}/%{name}.jar

%files javadoc
%doc licence-epl-1.0.html licence-lgpl-2.1.txt licence.txt
%{_javadocdir}/%{name}


%changelog
* Mon Jun 9 2014 Orion Poplawski <orion@cora.nwra.com> - 3.3-2
- Use BR junit

* Sun Jun 08 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.3-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Fri Feb 21 2014 Orion Poplawski <orion@cora.nwra.com> - 3.3-1
- Update to 3.3
- Require java-headless (bug #1068266)

* Tue Oct 22 2013 Orion Poplawski <orion@cora.nwra.com> - 3.2-7
- Remove versioned jars (bug #1022118)

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Feb 14 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_19_Mass_Rebuild

* Thu Jul 19 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_18_Mass_Rebuild

* Fri Jan 13 2012 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.2-3
- Rebuilt for https://fedoraproject.org/wiki/Fedora_17_Mass_Rebuild

* Thu Apr 21 2011 Orion Poplawski <orion@cora.nwra.com> - 3.2-2
- Specify Windows-1252 encoding
- Add src/java/net/htmlparser/jericho/nodoc/ to javadoc path

* Thu Apr 21 2011 Orion Poplawski <orion@cora.nwra.com> - 3.2-1
- Update to 3.2

* Wed Feb 09 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 3.1-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Dec 20 2010 Orion Poplawski <orion@cora.nwra.com> - 3.1-5
- ExcludeArch ppc64 - no java >= 1:1.6.0 on ppc64

* Fri Jul 30 2010 Orion Poplawski <orion@cora.nwra.com> - 3.1-4
- Add licenses to javadoc file

* Mon Jun 28 2010 Orion Poplawski <orion@cora.nwra.com> - 3.1-3
- Fix Groups again
- Link to jar in sample webapp

* Fri Jun 25 2010 Orion Poplawski <orion@cora.nwra.com> - 3.1-2
- Fix spelling errors
- Change package groups
- Fix Requires and BuildRequires
- Fix Summary
- Don't need to copy library for tests

* Mon Oct 5 2009 Orion Poplawski <orion@cora.nwra.com> - 3.1-1
- Initial Fedora Package
